from _typeshed import Incomplete

class DescriptorCalculationError(Exception): ...
class ClassificationError(Exception): ...

class ModelPackage:
    _descCalc: Incomplete
    _model: Incomplete
    _notes: Incomplete
    _dataSet: Incomplete
    _initialized: int
    _supplementalData: Incomplete
    def __init__(
        self,
        descCalc: Incomplete | None = ...,
        model: Incomplete | None = ...,
        dataSet: Incomplete | None = ...,
        notes: str = ...,
    ) -> None: ...
    def SetCalculator(self, calc) -> None: ...
    def GetCalculator(self): ...
    def SetModel(self, model) -> None: ...
    def GetModel(self): ...
    def SetDataset(self, data) -> None: ...
    def GetDataset(self): ...
    def SetNotes(self, notes) -> None: ...
    def GetNotes(self): ...
    def SetSupplementalData(self, suppD) -> None: ...
    def GetSupplementalData(self): ...
    def AddSupplementalData(self, data) -> None: ...
    def Classify(self, obj, label: str = ..., threshold: int = ...): ...
    def Init(self) -> None: ...
