from _typeshed import Incomplete

def StandardizeMatrix(mat): ...
def FormCovarianceMatrix(mat): ...
def FormCorrelationMatrix(mat): ...
def PrincipalComponents(mat, reverseOrder: int = ...): ...
def TransformPoints(tFormMat, pts): ...
def MeanAndDev(vect, sampleSD: int = ...): ...
def R2(orig, residSum): ...

tConfs: Incomplete
tTable: Incomplete

def GetConfidenceInterval(sd, n, level: int = ...): ...
