from _typeshed import Incomplete
from rdkit.VLib.Node import VLibNode as VLibNode

class FilterNode(VLibNode):
    _func: Incomplete
    _negate: Incomplete
    def __init__(
        self, func: Incomplete | None = ..., negate: int = ..., **kwargs
    ) -> None: ...
    def SetNegate(self, state) -> None: ...
    def Negate(self): ...
    def next(self): ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
