from _typeshed import Incomplete

class LazySig:
    computeFunc: Incomplete
    size: Incomplete
    _cache: Incomplete
    def __init__(self, computeFunc, sigSize) -> None: ...
    def __len__(self) -> int: ...
    def __getitem__(self, which): ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
