from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig

def SmilesToGif(
    smiles,
    fileNames,
    size=...,
    cmd: Incomplete | None = ...,
    dblSize: int = ...,
    frame: int = ...,
): ...
def SmilesToImage(smiles, **kwargs): ...
