from typing import Any

class ForceField:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddDistanceConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddExtraPoint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddFixedPoint(cls, ForceFields, unsignedint) -> Any: ...
    @classmethod
    def CalcEnergy(cls, ForceFields) -> Any: ...
    @classmethod
    def CalcGrad(cls, ForceFields) -> Any: ...
    @classmethod
    def Dimension(cls, ForceFields) -> Any: ...
    @classmethod
    def GetExtraPointPos(cls, ForceFields, unsignedint) -> Any: ...
    @classmethod
    def Initialize(cls, ForceFields) -> Any: ...
    @classmethod
    def MMFFAddAngleConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def MMFFAddDistanceConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def MMFFAddPositionConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def MMFFAddTorsionConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Minimize(cls, ForceFields) -> Any: ...
    @classmethod
    def MinimizeTrajectory(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def NumPoints(cls, ForceFields) -> Any: ...
    @classmethod
    def Positions(cls, ForceFields) -> Any: ...
    @classmethod
    def UFFAddAngleConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UFFAddDistanceConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UFFAddPositionConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UFFAddTorsionConstraint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class MMFFMolProperties:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetMMFFAngleBendParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMMFFAtomType(cls, ForceFields, unsignedint) -> Any: ...
    @classmethod
    def GetMMFFBondStretchParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMMFFFormalCharge(cls, ForceFields, unsignedint) -> Any: ...
    @classmethod
    def GetMMFFOopBendParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMMFFPartialCharge(cls, ForceFields, unsignedint) -> Any: ...
    @classmethod
    def GetMMFFStretchBendParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMMFFTorsionParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMMFFVdWParams(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetMMFFAngleTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFBondTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFDielectricConstant(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFDielectricModel(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFEleTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFOopTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFStretchBendTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFTorsionTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFVariant(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFVdWTerm(cls, ForceFields) -> Any: ...
    @classmethod
    def SetMMFFVerbosity(cls, ForceFields) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
