def log2(x): ...
def BurgesRiskBound(VCDim, nData, nWrong, conf): ...
def CristianiRiskBound(VCDim, nData, nWrong, conf): ...
def CherkasskyRiskBound(
    VCDim, nData, nWrong, conf, a1: float = ..., a2: float = ...
): ...
