from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import rdMolDescriptors as rdMolDescriptors

HDonorSmarts: Incomplete
HAcceptorSmarts: Incomplete
HeteroatomSmarts: Incomplete
RotatableBondSmarts: Incomplete
NHOHSmarts: Incomplete
NOCountSmarts: Incomplete
NumHDonors: Incomplete
_HDonors: Incomplete
NumHAcceptors: Incomplete
_HAcceptors: Incomplete
NumHeteroatoms: Incomplete
_Heteroatoms: Incomplete
NumRotatableBonds: Incomplete
_RotatableBonds: Incomplete
NOCount: Incomplete
NHOHCount: Incomplete
RingCount: Incomplete

def HeavyAtomCount(mol): ...

_bulkConvert: Incomplete
_cfn: Incomplete
_fn: Incomplete
nm: Incomplete
