from rdkit.ML.DecTree import ID3 as ID3

def GenRandomExamples(
    nVars: int = ...,
    randScale: float = ...,
    bitProb: float = ...,
    nExamples: int = ...,
    seed=...,
    addResults: int = ...,
): ...
