from rdkit import DataStructs as DataStructs, RDConfig as RDConfig
from rdkit.Dbase.DbConnection import DbConnect as DbConnect
from rdkit.ML import CompositeRun as CompositeRun
from rdkit.ML.Data import DataUtils as DataUtils, SplitData as SplitData, Stats as Stats

__VERSION_STRING: str

def cmp(t1, t2): ...
def message(msg, noRet: int = ..., dest=...) -> None: ...
def error(msg, dest=...) -> None: ...
def ScreenModel(
    mdl, descs, data, picking=..., indices=..., errorEstimate: int = ...
): ...
def AccumulateCounts(predictions, thresh: int = ..., sortIt: int = ...): ...
def MakePlot(
    details, final, counts, pickVects, nModels, nTrueActs: int = ...
) -> None: ...
def Usage() -> None: ...
