from typing import Any

def ComputeConfBox(RDKit) -> Any: ...
def ComputeConfDimsAndOffset(RDKit) -> Any: ...
def ComputeUnionBox(*args, **kwargs) -> Any: ...
def EncodeShape(RDKit, RDGeom) -> Any: ...
def ShapeProtrudeDist(*args, **kwargs) -> Any: ...
def ShapeTanimotoDist(*args, **kwargs) -> Any: ...
def ShapeTverskyIndex(*args, **kwargs) -> Any: ...
