from _typeshed import Incomplete

class VLibNode:
    _children: Incomplete
    _parents: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def __iter__(self): ...
    def next(self) -> None: ...
    def reset(self) -> None: ...
    def AddChild(self, child, notify: int = ...) -> None: ...
    def RemoveChild(self, child, notify: int = ...) -> None: ...
    def GetChildren(self): ...
    def AddParent(self, parent, notify: bool = ...) -> None: ...
    def RemoveParent(self, parent, notify: bool = ...) -> None: ...
    def GetParents(self): ...
    _destroyed: bool
    def Destroy(
        self, notify: bool = ..., propagateDown: bool = ..., propagateUp: bool = ...
    ) -> None: ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
