from _typeshed import Incomplete
from rdkit.ML.KNN import KNNModel as KNNModel

class KNNRegressionModel(KNNModel.KNNModel):
    _badExamples: Incomplete
    def __init__(self, k, attrs, dfunc, radius: Incomplete | None = ...) -> None: ...
    def type(self): ...
    def SetBadExamples(self, examples) -> None: ...
    def GetBadExamples(self): ...
    def NameModel(self, varNames) -> None: ...
    def PredictExample(
        self,
        example,
        appendExamples: int = ...,
        weightedAverage: int = ...,
        neighborList: Incomplete | None = ...,
    ): ...
