def CalcROC(scores, col): ...
def CalcAUC(scores, col): ...
def _RIEHelper(scores, col, alpha): ...
def CalcRIE(scores, col, alpha): ...
def CalcBEDROC(scores, col, alpha): ...
def CalcEnrichment(scores, col, fractions): ...
