from _typeshed import Incomplete

mcimport: Incomplete

def _myimport(
    name,
    globals: Incomplete | None = ...,
    locals: Incomplete | None = ...,
    fromlist: Incomplete | None = ...,
): ...
def set_gen_path(path) -> None: ...
