from _typeshed import Incomplete
from rdkit import Chem as Chem, RDConfig as RDConfig

defaultPatternFileName: Incomplete

def _CountMatches(mol, patt, unique: bool = ...): ...

fns: Incomplete

def _LoadPatterns(fileName: Incomplete | None = ...): ...

fn: Incomplete
