def CollectVotes(composite, data, badOnly): ...
def BuildVoteImage(
    nModels,
    data,
    values,
    trueValues=...,
    sortTrueVals: int = ...,
    xScale: int = ...,
    yScale: int = ...,
    addLine: int = ...,
): ...
def VoteAndBuildImage(
    composite,
    data,
    badOnly: int = ...,
    sortTrueVals: int = ...,
    xScale: int = ...,
    yScale: int = ...,
    addLine: int = ...,
): ...
def Usage() -> None: ...
