from _typeshed import Incomplete

class Color:
    def __init__(self, red: int = ..., green: int = ..., blue: int = ...) -> None: ...
    def __setattr__(self, name, value) -> None: ...
    def __mul__(self, x): ...
    def __rmul__(self, x): ...
    def __truediv__(self, x): ...
    def __div__(self, x): ...
    def __rdiv__(self, x): ...
    def __add__(self, x): ...
    def __sub__(self, x): ...
    def __repr__(self): ...
    def __hash__(self): ...
    def __cmp__(self, other): ...
    def toHexRGB(self): ...
    def toHexStr(self): ...

def HexColor(val): ...

aliceblue: Incomplete
antiquewhite: Incomplete
aqua: Incomplete
aquamarine: Incomplete
azure: Incomplete
beige: Incomplete
bisque: Incomplete
black: Incomplete
blanchedalmond: Incomplete
blue: Incomplete
blueviolet: Incomplete
brown: Incomplete
burlywood: Incomplete
cadetblue: Incomplete
chartreuse: Incomplete
chocolate: Incomplete
coral: Incomplete
cornflower: Incomplete
cornsilk: Incomplete
crimson: Incomplete
cyan: Incomplete
darkblue: Incomplete
darkcyan: Incomplete
darkgoldenrod: Incomplete
darkgray: Incomplete
darkgreen: Incomplete
darkkhaki: Incomplete
darkmagenta: Incomplete
darkolivegreen: Incomplete
darkorange: Incomplete
darkorchid: Incomplete
darkred: Incomplete
darksalmon: Incomplete
darkseagreen: Incomplete
darkslateblue: Incomplete
darkslategray: Incomplete
darkturquoise: Incomplete
darkviolet: Incomplete
deeppink: Incomplete
deepskyblue: Incomplete
dimgray: Incomplete
dodgerblue: Incomplete
firebrick: Incomplete
floralwhite: Incomplete
forestgreen: Incomplete
fuchsia: Incomplete
gainsboro: Incomplete
ghostwhite: Incomplete
gold: Incomplete
goldenrod: Incomplete
gray: Incomplete
grey = gray
green: Incomplete
greenyellow: Incomplete
honeydew: Incomplete
hotpink: Incomplete
indianred: Incomplete
indigo: Incomplete
ivory: Incomplete
khaki: Incomplete
lavender: Incomplete
lavenderblush: Incomplete
lawngreen: Incomplete
lemonchiffon: Incomplete
lightblue: Incomplete
lightcoral: Incomplete
lightcyan: Incomplete
lightgoldenrodyellow: Incomplete
lightgreen: Incomplete
lightgrey: Incomplete
lightpink: Incomplete
lightsalmon: Incomplete
lightseagreen: Incomplete
lightskyblue: Incomplete
lightslategray: Incomplete
lightsteelblue: Incomplete
lightyellow: Incomplete
lime: Incomplete
limegreen: Incomplete
linen: Incomplete
magenta: Incomplete
maroon: Incomplete
mediumaquamarine: Incomplete
mediumblue: Incomplete
mediumorchid: Incomplete
mediumpurple: Incomplete
mediumseagreen: Incomplete
mediumslateblue: Incomplete
mediumspringgreen: Incomplete
mediumturquoise: Incomplete
mediumvioletred: Incomplete
midnightblue: Incomplete
mintcream: Incomplete
mistyrose: Incomplete
moccasin: Incomplete
navajowhite: Incomplete
navy: Incomplete
oldlace: Incomplete
olive: Incomplete
olivedrab: Incomplete
orange: Incomplete
orangered: Incomplete
orchid: Incomplete
palegoldenrod: Incomplete
palegreen: Incomplete
paleturquoise: Incomplete
palevioletred: Incomplete
papayawhip: Incomplete
peachpuff: Incomplete
peru: Incomplete
pink: Incomplete
plum: Incomplete
powderblue: Incomplete
purple: Incomplete
red: Incomplete
rosybrown: Incomplete
royalblue: Incomplete
saddlebrown: Incomplete
salmon: Incomplete
sandybrown: Incomplete
seagreen: Incomplete
seashell: Incomplete
sienna: Incomplete
silver: Incomplete
skyblue: Incomplete
slateblue: Incomplete
slategray: Incomplete
snow: Incomplete
springgreen: Incomplete
steelblue: Incomplete
tan: Incomplete
teal: Incomplete
thistle: Incomplete
tomato: Incomplete
turquoise: Incomplete
violet: Incomplete
wheat: Incomplete
white: Incomplete
whitesmoke: Incomplete
yellow: Incomplete
yellowgreen: Incomplete
transparent: Incomplete
