from _typeshed import Incomplete
from rdkit.VLib.Node import VLibNode as VLibNode

class SupplyNode(VLibNode):
    _contents: Incomplete
    _pos: int
    def __init__(self, contents: Incomplete | None = ..., **kwargs) -> None: ...
    def reset(self) -> None: ...
    def next(self): ...
    def AddParent(self, parent, notify: int = ...) -> None: ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
