from rdkit.ML.InfoTheory import entropy as entropy

def FormCounts(
    bitVects, actVals, whichBit, nPossibleActs, nPossibleBitVals: int = ...
): ...
def CalcInfoGains(bitVects, actVals, nPossibleActs, nPossibleBitVals: int = ...): ...
def RankBits(bitVects, actVals, nPossibleBitVals: int = ..., metricFunc=...): ...
def AnalyzeSparseVects(bitVects, actVals): ...
def SparseRankBits(bitVects, actVals, metricFunc=...): ...
