from math import *
from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig

__DEBUG: bool
knownMethods: Incomplete

def HAS(strArg, composList, atomDict): ...
def SUM(strArg, composList, atomDict): ...
def MEAN(strArg, composList, atomDict): ...

AVG = MEAN

def DEV(strArg, composList, atomDict): ...
def MIN(strArg, composList, atomDict): ...
def MAX(strArg, composList, atomDict): ...
def _SubForAtomicVars(cExpr, varList, dictName): ...
def _SubForCompoundDescriptors(cExpr, varList, dictName): ...
def _SubMethodArgs(cExpr, knownMethods): ...
def CalcSingleCompoundDescriptor(compos, argVect, atomDict, propDict): ...
def CalcMultipleCompoundsDescriptor(composVect, argVect, atomDict, propDictList): ...
def _exampleCode() -> None: ...
