from _typeshed import Incomplete
from rdkit.Chem import ChemicalFeatures as ChemicalFeatures
from rdkit.Chem.Pharm2D.SigFactory import SigFactory as SigFactory

fdef: str
defaultBins: Incomplete

def _init() -> None: ...
