from typing import Any

def Compute2DCoords(RDKit) -> Any: ...
def Compute2DCoordsMimicDistmat(RDKit, boost) -> Any: ...
def GenerateDepictionMatching2DStructure(*args, **kwargs) -> Any: ...
def GenerateDepictionMatching3DStructure(*args, **kwargs) -> Any: ...
def NormalizeDepiction(RDKit) -> Any: ...
def SetPreferCoordGen(bool) -> Any: ...
def StraightenDepiction(RDKit) -> Any: ...
