from typing import Any

def InchiToInchiKey(*args, **kwargs) -> Any: ...
def InchiToMol(*args, **kwargs) -> Any: ...
def MolBlockToInchi(*args, **kwargs) -> Any: ...
def MolToInchi(RDKit) -> Any: ...
def MolToInchiKey(RDKit) -> Any: ...
