from rdkit.ML.DecTree import CrossValidate as CrossValidate, DecTree as DecTree

_verbose: int

def MaxCount(examples): ...
def _GetLocalError(node): ...
def _Pruner(node, level: int = ...): ...
def PruneTree(tree, trainExamples, testExamples, minimizeTestErrorOnly: int = ...): ...
def _testRandom() -> None: ...
def _testSpecific() -> None: ...
def _testChain() -> None: ...
