from . import InteractiveRenderer as InteractiveRenderer
from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import (
    Draw as Draw,
    rdChemReactions as rdChemReactions,
    rdchem as rdchem,
)
from rdkit.Chem.Draw import rdMolDraw2D as rdMolDraw2D

_canUse3D: bool
molSize: Incomplete
highlightSubstructs: bool
kekulizeStructures: bool
highlightByReactant: bool
ipython_useSVG: bool
ipython_showProperties: bool
ipython_maxProperties: int
ipython_3d: bool
molSize_3d: Incomplete
drawing_type_3d: str
bgcolor_3d: str
drawOptions: Incomplete

def addMolToView(
    mol, view, confId: int = ..., drawAs: Incomplete | None = ...
) -> None: ...
def drawMol3D(
    m,
    view: Incomplete | None = ...,
    confId: int = ...,
    drawAs: Incomplete | None = ...,
    bgColor: Incomplete | None = ...,
    size: Incomplete | None = ...,
): ...
def _toJSON(mol): ...
def _wrapHTMLIntoTable(html): ...
def _toHTML(mol): ...
def _toPNG(mol): ...
def _toSVG(mol): ...
def _toReactionPNG(rxn): ...
def _toReactionSVG(rxn): ...
def _toMolBundlePNG(bundle): ...
def _toMolBundleSVG(bundle): ...
def _GetSubstructMatch(mol, query, *args, **kwargs): ...
def _GetSubstructMatches(mol, query, *args, **kwargs): ...
def display_pil_image(img): ...

_MolsToGridImageSaved: Incomplete

def ShowMols(mols, maxMols: int = ..., **kwargs): ...
def _DrawBit(fn, *args, **kwargs): ...
def _DrawBits(fn, *args, **kwargs): ...

_DrawMorganBitSaved: Incomplete

def DrawMorganBit(mol, bitId, bitInfo, drawOptions=..., **kwargs): ...

_DrawMorganBitsSaved: Incomplete

def DrawMorganBits(*args, drawOptions=..., **kwargs): ...

_DrawRDKitBitSaved: Incomplete

def DrawRDKitBit(mol, bitId, bitInfo, drawOptions=..., **kwargs): ...

_DrawRDKitBitsSaved: Incomplete

def DrawRDKitBits(*args, drawOptions=..., **kwargs): ...

_rendererInstalled: bool

def EnableSubstructMatchRendering() -> None: ...

_methodsToDelete: Incomplete

def InstallIPythonRenderer(): ...
def DisableSubstructMatchRendering() -> None: ...
def UninstallIPythonRenderer() -> None: ...
