from typing import Any, ClassVar

class CoordGenParams:
    __instance_size__: ClassVar[int] = ...
    coordgenScaling: Any
    dbg_useConstrained: Any
    dbg_useFixed: Any
    minimizerPrecision: Any
    templateFileDir: Any
    treatNonterminalBondsToMetalAsZOBs: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def SetCoordMap(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetTemplateMol(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def sketcherBestPrecision(self) -> Any: ...
    @property
    def sketcherCoarsePrecision(self) -> Any: ...
    @property
    def sketcherQuickPrecision(self) -> Any: ...
    @property
    def sketcherStandardPrecision(self) -> Any: ...

def AddCoords(RDKit) -> Any: ...
def SetDefaultTemplateFileDir(*args, **kwargs) -> Any: ...
