from _typeshed import Incomplete

def _ConvertModelPerformance(perf, modelPerf) -> None: ...
def PackageToXml(
    pkg,
    summary: str = ...,
    trainingDataId: str = ...,
    dataPerformance=...,
    recommendedThreshold: Incomplete | None = ...,
    classDescriptions: Incomplete | None = ...,
    modelType: Incomplete | None = ...,
    modelOrganism: Incomplete | None = ...,
): ...
