from typing import Any

def CanonicalizeConformer(*args, **kwargs) -> Any: ...
def CanonicalizeMol(RDKit) -> Any: ...
def ComputeCanonicalTransform(*args, **kwargs) -> Any: ...
def ComputeCentroid(RDKit) -> Any: ...
def ComputePrincipalAxesAndMoments(*args, **kwargs) -> Any: ...
def ComputePrincipalAxesAndMomentsFromGyrationMatrix(*args, **kwargs) -> Any: ...
def GetAngleDeg(*args, **kwargs) -> Any: ...
def GetAngleRad(*args, **kwargs) -> Any: ...
def GetBondLength(*args, **kwargs) -> Any: ...
def GetDihedralDeg(*args, **kwargs) -> Any: ...
def GetDihedralRad(*args, **kwargs) -> Any: ...
def SetAngleDeg(*args, **kwargs) -> Any: ...
def SetAngleRad(*args, **kwargs) -> Any: ...
def SetBondLength(*args, **kwargs) -> Any: ...
def SetDihedralDeg(*args, **kwargs) -> Any: ...
def SetDihedralRad(*args, **kwargs) -> Any: ...
def TransformConformer(RDKit, boost) -> Any: ...
