from collections.abc import Iterable
from typing import Any, ClassVar, Literal, Optional, Sequence, overload

import numpy as np

ALLOW_CHARGE_SEPARATION: ResonanceFlags
ALLOW_INCOMPLETE_OCTETS: ResonanceFlags
AllProps: PropertyPickleOptions
AtomProps: PropertyPickleOptions
BondProps: PropertyPickleOptions
CHI_OTHER: ChiralType
CHI_TETRAHEDRAL_CCW: ChiralType
CHI_TETRAHEDRAL_CW: ChiralType
CHI_UNSPECIFIED: ChiralType
COMPOSITE_AND: CompositeQueryType
COMPOSITE_OR: CompositeQueryType
COMPOSITE_XOR: CompositeQueryType
ComputedProps: PropertyPickleOptions
CoordsAsDouble: PropertyPickleOptions
KEKULE_ALL: ResonanceFlags
MolProps: PropertyPickleOptions
NoConformers: PropertyPickleOptions
NoProps: PropertyPickleOptions
PrivateProps: PropertyPickleOptions
QueryAtomData: PropertyPickleOptions
STEREO_ABSOLUTE: StereoGroupType
STEREO_AND: StereoGroupType
STEREO_OR: StereoGroupType
UNCONSTRAINED_ANIONS: ResonanceFlags
UNCONSTRAINED_CATIONS: ResonanceFlags

class Atom:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def DescribeQuery(cls, RDKit) -> Any: ...
    def GetAtomMapNum(self) -> int: ...
    def GetAtomicNum(self) -> int: ...
    @classmethod
    def GetBonds(cls, RDKit) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetChiralTag(cls, RDKit) -> Any: ...
    @classmethod
    def GetDegree(cls, RDKit) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetExplicitBitVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetExplicitValence(cls, RDKit) -> Any: ...
    @classmethod
    def GetFormalCharge(cls, RDKit) -> Any: ...
    @classmethod
    def GetHybridization(cls, RDKit) -> Any: ...
    def GetIdx(self) -> int: ...
    @classmethod
    def GetImplicitValence(cls, RDKit) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIsAromatic(cls, RDKit) -> Any: ...
    @classmethod
    def GetIsotope(cls, RDKit) -> Any: ...
    @classmethod
    def GetMass(cls, RDKit) -> Any: ...
    @classmethod
    def GetMonomerInfo(cls, RDKit) -> Any: ...
    @classmethod
    def GetNeighbors(cls, RDKit) -> Any: ...
    @classmethod
    def GetNoImplicit(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumExplicitHs(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumImplicitHs(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumRadicalElectrons(cls, RDKit) -> Any: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetPDBResidueInfo(cls, RDKit) -> Any: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetQueryType(cls, RDKit) -> Any: ...
    def GetSmarts(
        self,
        doKekule: Optional[bool] = False,
        allHsExplicit: Optional[bool] = False,
        isomericSmiles: Optional[bool] = True,
    ) -> str: ...
    @classmethod
    def GetSymbol(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalDegree(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalNumHs(cls, RDKit) -> Any: ...
    @classmethod
    def GetTotalValence(cls, RDKit) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasQuery(cls, RDKit) -> Any: ...
    @classmethod
    def InvertChirality(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRing(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRingSize(cls, RDKit, int) -> Any: ...
    @classmethod
    def Match(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def NeedsUpdatePropertyCache(cls, RDKit) -> Any: ...
    @classmethod
    def SetAtomMapNum(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetAtomicNum(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetChiralTag(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetExplicitBitVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetFormalCharge(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetHybridization(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIsAromatic(cls, RDKit, bool) -> Any: ...
    def SetIsotope(self, arg1: int) -> None: ...
    @classmethod
    def SetMonomerInfo(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetNoImplicit(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetNumExplicitHs(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetNumRadicalElectrons(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetPDBResidueInfo(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def UpdatePropertyCache(cls, RDKit) -> Any: ...
    @classmethod
    def __copy__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AtomKekulizeException(AtomSanitizeException): ...

class AtomMonomerInfo:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetMonomerType(cls, RDKit) -> Any: ...
    @classmethod
    def GetName(cls, RDKit) -> Any: ...
    @classmethod
    def SetMonomerType(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetName(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AtomMonomerType:
    OTHER: ClassVar[AtomMonomerType] = ...
    PDBRESIDUE: ClassVar[AtomMonomerType] = ...
    UNKNOWN: ClassVar[AtomMonomerType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class AtomPDBResidueInfo(AtomMonomerInfo):
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAltLoc(cls, RDKit) -> Any: ...
    @classmethod
    def GetChainId(cls, RDKit) -> Any: ...
    @classmethod
    def GetInsertionCode(cls, RDKit) -> Any: ...
    @classmethod
    def GetIsHeteroAtom(cls, RDKit) -> Any: ...
    @classmethod
    def GetOccupancy(cls, RDKit) -> Any: ...
    @classmethod
    def GetResidueName(cls, RDKit) -> Any: ...
    @classmethod
    def GetResidueNumber(cls, RDKit) -> Any: ...
    @classmethod
    def GetSecondaryStructure(cls, RDKit) -> Any: ...
    @classmethod
    def GetSegmentNumber(cls, RDKit) -> Any: ...
    @classmethod
    def GetSerialNumber(cls, RDKit) -> Any: ...
    @classmethod
    def GetTempFactor(cls, RDKit) -> Any: ...
    @classmethod
    def SetAltLoc(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetChainId(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetInsertionCode(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIsHeteroAtom(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetOccupancy(cls, RDKit, double) -> Any: ...
    @classmethod
    def SetResidueName(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetResidueNumber(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetSecondaryStructure(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetSegmentNumber(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetSerialNumber(cls, RDKit, int) -> Any: ...
    @classmethod
    def SetTempFactor(cls, RDKit, double) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class AtomSanitizeException(MolSanitizeException): ...
class AtomValenceException(AtomSanitizeException): ...

class Bond:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def DescribeQuery(cls, RDKit) -> Any: ...
    @classmethod
    def GetBeginAtom(cls, RDKit) -> Any: ...
    @classmethod
    def GetBeginAtomIdx(cls, RDKit) -> Any: ...
    @classmethod
    def GetBondDir(cls, RDKit) -> Any: ...
    @classmethod
    def GetBondType(cls, RDKit) -> Any: ...
    @classmethod
    def GetBondTypeAsDouble(cls, RDKit) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetEndAtom(cls, RDKit) -> Any: ...
    @classmethod
    def GetEndAtomIdx(cls, RDKit) -> Any: ...
    def GetIdx(self) -> int: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIsAromatic(cls, RDKit) -> Any: ...
    @classmethod
    def GetIsConjugated(cls, RDKit) -> Any: ...
    @classmethod
    def GetOtherAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetOtherAtomIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetSmarts(cls, RDKit) -> Any: ...
    @classmethod
    def GetStereo(cls, RDKit) -> Any: ...
    @classmethod
    def GetStereoAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetValenceContrib(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasQuery(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRing(cls, RDKit) -> Any: ...
    @classmethod
    def IsInRingSize(cls, RDKit, int) -> Any: ...
    @classmethod
    def Match(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBondDir(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBondType(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIsAromatic(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetIsConjugated(cls, RDKit, bool) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetStereo(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetStereoAtoms(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class BondDir:
    BEGINDASH: ClassVar[BondDir] = ...
    BEGINWEDGE: ClassVar[BondDir] = ...
    EITHERDOUBLE: ClassVar[BondDir] = ...
    ENDDOWNRIGHT: ClassVar[BondDir] = ...
    ENDUPRIGHT: ClassVar[BondDir] = ...
    NONE: ClassVar[BondDir] = ...
    UNKNOWN: ClassVar[BondDir] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class BondStereo:
    STEREOANY: ClassVar[BondStereo] = ...
    STEREOCIS: ClassVar[BondStereo] = ...
    STEREOE: ClassVar[BondStereo] = ...
    STEREONONE: ClassVar[BondStereo] = ...
    STEREOTRANS: ClassVar[BondStereo] = ...
    STEREOZ: ClassVar[BondStereo] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class BondType:
    AROMATIC: ClassVar[BondType] = ...
    DATIVE: ClassVar[BondType] = ...
    DATIVEL: ClassVar[BondType] = ...
    DATIVEONE: ClassVar[BondType] = ...
    DATIVER: ClassVar[BondType] = ...
    DOUBLE: ClassVar[BondType] = ...
    FIVEANDAHALF: ClassVar[BondType] = ...
    FOURANDAHALF: ClassVar[BondType] = ...
    HEXTUPLE: ClassVar[BondType] = ...
    HYDROGEN: ClassVar[BondType] = ...
    IONIC: ClassVar[BondType] = ...
    ONEANDAHALF: ClassVar[BondType] = ...
    OTHER: ClassVar[BondType] = ...
    QUADRUPLE: ClassVar[BondType] = ...
    QUINTUPLE: ClassVar[BondType] = ...
    SINGLE: ClassVar[BondType] = ...
    THREEANDAHALF: ClassVar[BondType] = ...
    THREECENTER: ClassVar[BondType] = ...
    TRIPLE: ClassVar[BondType] = ...
    TWOANDAHALF: ClassVar[BondType] = ...
    UNSPECIFIED: ClassVar[BondType] = ...
    ZERO: ClassVar[BondType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class ChiralType:
    CHI_OTHER: ClassVar[ChiralType] = ...
    CHI_TETRAHEDRAL_CCW: ClassVar[ChiralType] = ...
    CHI_TETRAHEDRAL_CW: ClassVar[ChiralType] = ...
    CHI_UNSPECIFIED: ClassVar[ChiralType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class CompositeQueryType:
    COMPOSITE_AND: ClassVar[CompositeQueryType] = ...
    COMPOSITE_OR: ClassVar[CompositeQueryType] = ...
    COMPOSITE_XOR: ClassVar[CompositeQueryType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class Conformer:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ClearComputedProps(cls, RDKit) -> Any: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtomPosition(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetId(cls, RDKit) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    def GetNumAtoms(self) -> int: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    def GetPositions(
        self,
    ) -> np.ndarray[tuple[int, Literal[3]], np.dtype[np.float64]]: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Is3D(cls, RDKit) -> Any: ...
    @classmethod
    def Set3D(cls, RDKit, bool) -> Any: ...
    @overload
    @classmethod
    def SetAtomPosition(cls, RDKit, unsignedint, boost) -> Any: ...
    @overload
    @classmethod
    def SetAtomPosition(cls, RDKit, unsignedint, RDGeom) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetId(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class EditableMol:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def BeginBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def CommitBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def GetMol(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveAtom(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def RemoveBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def RollbackBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class FixedMolSizeMolBundle(MolBundle):
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class HybridizationType:
    OTHER: ClassVar[HybridizationType] = ...
    S: ClassVar[HybridizationType] = ...
    SP: ClassVar[HybridizationType] = ...
    SP2: ClassVar[HybridizationType] = ...
    SP3: ClassVar[HybridizationType] = ...
    SP3D: ClassVar[HybridizationType] = ...
    SP3D2: ClassVar[HybridizationType] = ...
    UNSPECIFIED: ClassVar[HybridizationType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class KekulizeException(MolSanitizeException): ...

class Mol:
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddConformer(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ClearComputedProps(cls, RDKit) -> Any: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Compute2DCoords(cls, RDKit) -> Any: ...
    @classmethod
    def ComputeGasteigerCharges(cls, RDKit) -> Any: ...
    @classmethod
    def Debug(cls, RDKit) -> Any: ...
    @classmethod
    def GetAromaticAtoms(cls, boost) -> Any: ...
    def GetAtomWithIdx(self, idx: int) -> Atom: ...
    def GetAtoms(self) -> Sequence[Atom]: ...
    def GetAtomsMatchingQuery(self, arg2: QueryAtom) -> Sequence[Atom]: ...
    @classmethod
    def GetBondBetweenAtoms(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBondWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetBonds(cls, boost) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    def GetConformer(self, id: int = -1) -> Conformer: ...
    def GetConformers(self) -> Sequence[Conformer]: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    def GetNumAtoms(self, onlyHeavy: int = -1, onlyExplicit: bool = True) -> int: ...
    @classmethod
    def GetNumBonds(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumConformers(cls, RDKit) -> Any: ...
    def GetNumHeavyAtoms(self) -> int: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetRingInfo(cls, RDKit) -> Any: ...
    @classmethod
    def GetStereoGroups(cls, RDKit) -> Any: ...
    @classmethod
    def GetSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetSubstructMatches(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def NeedsUpdatePropertyCache(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveAllConformers(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveConformer(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @overload
    @classmethod
    def ToBinary(cls, RDKit) -> Any: ...
    @overload
    @classmethod
    def ToBinary(cls, RDKit, unsignedint) -> Any: ...
    def UpdatePropertyCache(self, strict=True) -> None: ...
    @classmethod
    def __copy__(cls, boost) -> Any: ...
    @classmethod
    def __deepcopy__(cls) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class MolBundle:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddMol(cls, RDKit, boost) -> Any: ...
    @classmethod
    def GetMol(cls, RDKit, unsignedlong) -> Any: ...
    @classmethod
    def GetSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetSubstructMatches(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Size(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, unsignedlong) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class MolSanitizeException(ValueError): ...

class PeriodicTable:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAbundanceForIsotope(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtomicNumber(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtomicWeight(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetDefaultValence(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetElementSymbol(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetMassForIsotope(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetMostCommonIsotope(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetMostCommonIsotopeMass(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetNOuterElecs(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetRb0(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetRcovalent(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetRvdw(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetValenceList(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class PropertyPickleOptions:
    AllProps: ClassVar[PropertyPickleOptions] = ...
    AtomProps: ClassVar[PropertyPickleOptions] = ...
    BondProps: ClassVar[PropertyPickleOptions] = ...
    ComputedProps: ClassVar[PropertyPickleOptions] = ...
    CoordsAsDouble: ClassVar[PropertyPickleOptions] = ...
    MolProps: ClassVar[PropertyPickleOptions] = ...
    NoConformers: ClassVar[PropertyPickleOptions] = ...
    NoProps: ClassVar[PropertyPickleOptions] = ...
    PrivateProps: ClassVar[PropertyPickleOptions] = ...
    QueryAtomData: ClassVar[PropertyPickleOptions] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class QueryAtom(Atom):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ExpandQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class QueryBond(Bond):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def ExpandQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetQuery(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class RWMol(Mol):
    __instance_size__: ClassVar[int] = ...
    __safe_for_unpickling__: ClassVar[bool] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def BeginBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def CommitBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def GetMol(cls, RDKit) -> Any: ...
    @classmethod
    def InsertMol(cls, *args, **kwargs) -> Any: ...
    def RemoveAtom(self, idx: int) -> None: ...
    @classmethod
    def RemoveBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceAtom(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def ReplaceBond(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def RollbackBatchEdit(cls, RDKit) -> Any: ...
    @classmethod
    def SetStereoGroups(cls, RDKit, boost) -> Any: ...
    @classmethod
    def __copy__(cls, boost) -> Any: ...
    @classmethod
    def __deepcopy__(cls) -> Any: ...
    @classmethod
    def __enter__(cls, RDKit) -> Any: ...
    @classmethod
    def __exit__(cls, type, value, traceback) -> Any: ...
    @classmethod
    def __getinitargs__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class ResonanceFlags:
    ALLOW_CHARGE_SEPARATION: ClassVar[ResonanceFlags] = ...
    ALLOW_INCOMPLETE_OCTETS: ClassVar[ResonanceFlags] = ...
    KEKULE_ALL: ClassVar[ResonanceFlags] = ...
    UNCONSTRAINED_ANIONS: ClassVar[ResonanceFlags] = ...
    UNCONSTRAINED_CATIONS: ClassVar[ResonanceFlags] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class ResonanceMolSupplier:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def Enumerate(cls, RDKit) -> Any: ...
    @classmethod
    def GetAtomConjGrpIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetBondConjGrpIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetIsEnumerated(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumConjGrps(cls, RDKit) -> Any: ...
    @classmethod
    def GetProgressCallback(cls, RDKit) -> Any: ...
    @classmethod
    def GetSubstructMatch(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetSubstructMatches(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetNumThreads(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetProgressCallback(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def WasCanceled(cls, RDKit) -> Any: ...
    @classmethod
    def atEnd(cls, RDKit) -> Any: ...
    @classmethod
    def reset(cls, RDKit) -> Any: ...
    @classmethod
    def __getitem__(cls, RDKit, int) -> Any: ...
    @classmethod
    def __iter__(cls, RDKit) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __next__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class ResonanceMolSupplierCallback:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetMaxStructures(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumConjGrps(cls, RDKit) -> Any: ...
    @classmethod
    def GetNumDiverseStructures(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetNumStructures(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __call__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class RingInfo:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddRing(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreAtomsInSameRing(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreAtomsInSameRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreBondsInSameRing(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreBondsInSameRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AreRingFamiliesInitialized(cls, RDKit) -> Any: ...
    @classmethod
    def AtomMembers(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AtomRingFamilies(cls, RDKit) -> Any: ...
    @classmethod
    def AtomRingSizes(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AtomRings(cls, RDKit) -> Any: ...
    @classmethod
    def BondMembers(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def BondRingFamilies(cls, RDKit) -> Any: ...
    @classmethod
    def BondRingSizes(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def BondRings(cls, RDKit) -> Any: ...
    @classmethod
    def IsAtomInRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def IsBondInRingOfSize(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def MinAtomRingSize(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def MinBondRingSize(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def NumAtomRings(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def NumBondRings(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def NumRelevantCycles(cls, RDKit) -> Any: ...
    @classmethod
    def NumRingFamilies(cls, RDKit) -> Any: ...
    @classmethod
    def NumRings(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class StereoDescriptor:
    Bond_Cis: ClassVar[StereoDescriptor] = ...
    Bond_Trans: ClassVar[StereoDescriptor] = ...
    NoValue: ClassVar[StereoDescriptor] = ...
    Tet_CCW: ClassVar[StereoDescriptor] = ...
    Tet_CW: ClassVar[StereoDescriptor] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoGroup:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetGroupType(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class StereoGroupType:
    STEREO_ABSOLUTE: ClassVar[StereoGroupType] = ...
    STEREO_AND: ClassVar[StereoGroupType] = ...
    STEREO_OR: ClassVar[StereoGroupType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoGroup_vect:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class StereoInfo:
    __instance_size__: ClassVar[int] = ...
    centeredOn: Any
    descriptor: Any
    specified: Any
    type: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def NOATOM(self) -> Any: ...
    @property
    def controllingAtoms(self) -> Any: ...

class StereoSpecified:
    Specified: ClassVar[StereoSpecified] = ...
    Unknown: ClassVar[StereoSpecified] = ...
    Unspecified: ClassVar[StereoSpecified] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class StereoType:
    Atom_Tetrahedral: ClassVar[StereoType] = ...
    Bond_Atropisomer: ClassVar[StereoType] = ...
    Bond_Cumulene_Even: ClassVar[StereoType] = ...
    Bond_Double: ClassVar[StereoType] = ...
    Unspecified: ClassVar[StereoType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class SubstanceGroup:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def AddAtomWithBookmark(cls, RDKit, int) -> Any: ...
    @classmethod
    def AddAtomWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AddAttachPoint(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddBondWithBookmark(cls, RDKit, int) -> Any: ...
    @classmethod
    def AddBondWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def AddBracket(cls, RDKit, boost) -> Any: ...
    @classmethod
    def AddCState(cls, RDKit, unsignedint, RDGeom) -> Any: ...
    @classmethod
    def AddParentAtomWithBookmark(cls, RDKit, int) -> Any: ...
    @classmethod
    def AddParentAtomWithIdx(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def ClearAttachPoints(cls, RDKit) -> Any: ...
    @classmethod
    def ClearBrackets(cls, RDKit) -> Any: ...
    @classmethod
    def ClearCStates(cls, RDKit) -> Any: ...
    @classmethod
    def ClearProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetAttachPoints(cls, RDKit) -> Any: ...
    @classmethod
    def GetBonds(cls, RDKit) -> Any: ...
    @classmethod
    def GetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetBrackets(cls, RDKit) -> Any: ...
    @classmethod
    def GetCStates(cls, RDKit) -> Any: ...
    @classmethod
    def GetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetIndexInMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetOwningMol(cls, RDKit) -> Any: ...
    @classmethod
    def GetParentAtoms(cls, RDKit) -> Any: ...
    @classmethod
    def GetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetPropNames(cls, RDKit) -> Any: ...
    @classmethod
    def GetPropsAsDict(cls, RDKit) -> Any: ...
    @classmethod
    def GetStringVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def GetUnsignedVectProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def HasProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetAtoms(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetBonds(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetBoolProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetDoubleProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetIntProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetParentAtoms(cls, RDKit, boost) -> Any: ...
    @classmethod
    def SetProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def SetUnsignedProp(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class SubstanceGroupAttach:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def aIdx(self) -> Any: ...
    @property
    def id(self) -> Any: ...
    @property
    def lvIdx(self) -> Any: ...

class SubstanceGroupCState:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @property
    def bondIdx(self) -> Any: ...
    @property
    def vector(self) -> Any: ...

class SubstanceGroup_VECT:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class SubstructMatchParameters:
    __instance_size__: ClassVar[int] = ...
    aromaticMatchesConjugated: Any
    maxMatches: Any
    numThreads: Any
    recursionPossible: Any
    uniquify: Any
    useChirality: Any
    useEnhancedStereo: Any
    useGenericMatchers: Any
    useQueryQueryMatches: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def setExtraFinalCheck(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROAtomSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROBondSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROConformerSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _ROQAtomSeq:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __next__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppAtomKekulizeException(_cppMolSanitizeException):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAtomIndices(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppAtomSanitizeException(_cppMolSanitizeException):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetAtomIdx(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppAtomValenceException(_cppAtomSanitizeException):
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _cppMolSanitizeException:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def GetType(cls, RDKit) -> Any: ...
    @classmethod
    def Message(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _listN5boost10shared_ptrIN5RDKit9ConformerEEE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class _listPN5RDKit4AtomE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

class _listPN5RDKit4BondE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

def AddMolSubstanceGroup(*args, **kwargs) -> Any: ...
def ClearMolSubstanceGroups(RDKit) -> Any: ...
def CreateMolSubstanceGroup(*args, **kwargs) -> Any: ...
def CreateStereoGroup(*args, **kwargs) -> Any: ...
def GetAtomAlias(RDKit) -> Any: ...
def GetAtomRLabel(RDKit) -> Any: ...
def GetAtomValue(RDKit) -> Any: ...
def GetDefaultPickleProperties() -> Any: ...
def GetMolSubstanceGroupWithIdx(RDKit, unsignedint) -> Any: ...
def GetMolSubstanceGroups(RDKit) -> Any: ...
def GetPeriodicTable() -> Any: ...
def GetSupplementalSmilesLabel(RDKit) -> Any: ...
def SetAtomAlias(*args, **kwargs) -> Any: ...
def SetAtomRLabel(RDKit, int) -> Any: ...
def SetAtomValue(*args, **kwargs) -> Any: ...
def SetDefaultPickleProperties(unsignedint) -> Any: ...
def SetSupplementalSmilesLabel(*args, **kwargs) -> Any: ...
def _HasSubstructMatchStr(*args, **kwargs) -> Any: ...
def tossit() -> Any: ...
