from _typeshed import Incomplete
from rdkit.DataStructs.TopNContainer import TopNContainer as TopNContainer

class KNNModel:
    def __init__(self, k, attrs, dfunc, radius: Incomplete | None = ...) -> None: ...
    _examples: Incomplete
    _trainingExamples: Incomplete
    _testExamples: Incomplete
    _k: Incomplete
    _attrs: Incomplete
    _dfunc: Incomplete
    _name: str
    _radius: Incomplete
    def _setup(self, k, attrs, dfunc, radius) -> None: ...
    def GetName(self): ...
    def SetName(self, name) -> None: ...
    def GetExamples(self): ...
    def SetExamples(self, examples) -> None: ...
    def GetTrainingExamples(self): ...
    def SetTrainingExamples(self, examples) -> None: ...
    def GetTestExamples(self): ...
    def SetTestExamples(self, examples) -> None: ...
    def GetNeighbors(self, example): ...
