from typing import Any, ClassVar

class AbbreviationDefinition:
    __instance_size__: ClassVar[int] = ...
    displayLabel: Any
    displayLabelW: Any
    label: Any
    mol: Any
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class _vectN5RDKit13Abbreviations22AbbreviationDefinitionE:
    __instance_size__: ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def append(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def extend(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def __contains__(cls, other) -> Any: ...
    @classmethod
    def __delitem__(cls, other) -> Any: ...
    @classmethod
    def __getitem__(cls, index) -> Any: ...
    @classmethod
    def __iter__(cls, boost, std) -> Any: ...
    @classmethod
    def __len__(cls) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...
    @classmethod
    def __setitem__(cls, index, object) -> Any: ...

def CondenseAbbreviationSubstanceGroups(RDKit) -> Any: ...
def CondenseMolAbbreviations(RDKit, boost) -> Any: ...
def GetDefaultAbbreviations() -> Any: ...
def GetDefaultLinkers() -> Any: ...
def LabelMolAbbreviations(RDKit, boost) -> Any: ...
def ParseAbbreviations(*args, **kwargs) -> Any: ...
def ParseLinkers(*args, **kwargs) -> Any: ...
