from . import fontinfo as fontinfo, latin1MetricsCache as latin1MetricsCache
from _typeshed import Incomplete

_stdenc_widths: Incomplete
ascent_descent: Incomplete
_Widths: Incomplete

def stringwidth(text, font, encoding): ...
