from rdkit.DataStructs.VectCollection import VectCollection as VectCollection
from rdkit.ML.DecTree import DecTree as DecTree

class SigTreeNode(DecTree.DecTreeNode):
    def NameModel(self, *args, **kwargs) -> None: ...
    def ClassifyExample(self, example, appendExamples: int = ...): ...
    def __init__(self, *args, **kwargs) -> None: ...
