from typing import Any

def GetUFFAngleBendParams(*args, **kwargs) -> Any: ...
def GetUFFBondStretchParams(*args, **kwargs) -> Any: ...
def GetUFFInversionParams(*args, **kwargs) -> Any: ...
def GetUFFTorsionParams(*args, **kwargs) -> Any: ...
def GetUFFVdWParams(*args, **kwargs) -> Any: ...
def MMFFGetMoleculeForceField(RDKit, ForceFields) -> Any: ...
def MMFFGetMoleculeProperties(RDKit) -> Any: ...
def MMFFHasAllMoleculeParams(RDKit) -> Any: ...
def MMFFOptimizeMolecule(RDKit) -> Any: ...
def MMFFOptimizeMoleculeConfs(RDKit) -> Any: ...
def MMFFSanitizeMolecule(RDKit) -> Any: ...
def OptimizeMolecule(ForceFields) -> Any: ...
def OptimizeMoleculeConfs(RDKit, ForceFields) -> Any: ...
def UFFGetMoleculeForceField(RDKit) -> Any: ...
def UFFHasAllMoleculeParams(RDKit) -> Any: ...
def UFFOptimizeMolecule(RDKit) -> Any: ...
def UFFOptimizeMoleculeConfs(RDKit) -> Any: ...
