from rdkit.VLib.NodeLib import *
from _typeshed import Incomplete
from rdkit import Chem as Chem, RDConfig as RDConfig
from rdkit.VLib import Filter as Filter, Supply as Supply

smis: Incomplete
mols: Incomplete
supplier: Incomplete
metals: str
smaFilter: Incomplete
salts: Incomplete
remover: Incomplete
atsFilter: Incomplete
dupeFilter: Incomplete
io: Incomplete
output: Incomplete
