from _typeshed import Incomplete
from rdkit.Chem import ChemicalFeatures as ChemicalFeatures

class FeatMapPoint(ChemicalFeatures.FreeChemicalFeature):
    weight: float
    featDirs: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def initFromFeat(self, feat) -> None: ...
    def GetDist2(self, other): ...
    def GetDirMatch(self, other, useBest: bool = ...): ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
