from _typeshed import Incomplete
from rdkit import Geometry as Geometry
from rdkit.Chem.FeatMaps import FeatMapPoint as FeatMapPoint, FeatMaps as FeatMaps

class FeatMapParseError(ValueError): ...

class FeatMapParser:
    data: Incomplete
    _lineNum: int
    def __init__(
        self, file: Incomplete | None = ..., data: Incomplete | None = ...
    ) -> None: ...
    def SetData(self, data) -> None: ...
    def _NextLine(self): ...
    def Parse(self, featMap: Incomplete | None = ...): ...
    def ParseParamBlock(self): ...
    def _parsePoint(self, txt): ...
    def ParseFeatPointBlock(self): ...
