from _typeshed import Incomplete
from rdkit import RDConfig as RDConfig
from rdkit.Dbase import DbModule as DbModule
from rdkit.Dbase.DbConnection import DbConnect as DbConnect

def SetDefaults(runDetails): ...

class CompositeRun:
    fields: Incomplete
    def _CreateTable(self, cn, tblName): ...
    def Store(
        self, db: str = ..., table: str = ..., user: str = ..., password: str = ...
    ) -> None: ...
    def GetDataSet(self, **kwargs): ...
    def GetDataSetInfo(self, **kwargs): ...
