from _typeshed import Incomplete

vsaBins: Incomplete

def VSA_EState_(mol, bins: Incomplete | None = ..., force: int = ...): ...

estateBins: Incomplete

def EState_VSA_(mol, bins: Incomplete | None = ..., force: int = ...): ...
def _descriptorDocstring(name, nbin, bins): ...
def _descriptor_VSA_EState(nbin): ...
def _descriptor_EState_VSA(nbin): ...
def _InstallDescriptors() -> None: ...
