from _typeshed import Incomplete

class MolSupplier:
    def __init__(self) -> None: ...
    def Reset(self) -> None: ...
    def __iter__(self): ...
    def next(self): ...
    def NextMol(self) -> None: ...
    __next__: Incomplete
