from _typeshed import Incomplete
from rdkit import Chem as Chem, DataStructs as DataStructs
from rdkit.Chem.Fingerprints import (
    DbFpSupplier as DbFpSupplier,
    FingerprintMols as FingerprintMols,
)
from rdkit.DataStructs.TopNContainer import TopNContainer as TopNContainer
from rdkit.Dbase import DbModule as DbModule
from rdkit.Dbase.DbConnection import DbConnect as DbConnect

def _ConnectToDatabase(details) -> DbConnect: ...
def _ConstructSQL(details, extraFields: str = ...): ...
def ScreenInDb(details, mol): ...
def GetFingerprints(details): ...
def ScreenFingerprints(
    details, data, mol: Incomplete | None = ..., probeFp: Incomplete | None = ...
): ...
def ScreenFromDetails(details, mol: Incomplete | None = ...): ...

_usageDoc: str
