from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.Chem import rdMolDescriptors as rdMolDescriptors

def ExplainAtomCode(code, branchSubtract: int = ..., includeChirality: bool = ...): ...

GetAtomCode: Incomplete

def NumPiElectrons(atom): ...
def BitsInCommon(v1, v2): ...
def DiceSimilarity(v1, v2, bounds: Incomplete | None = ...): ...
def Dot(v1, v2): ...
def CosineSimilarity(v1, v2): ...
def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
