def GetNodeList(cluster): ...
def GetNodesDownToCentroids(cluster, above: int = ...): ...
def FindClusterCentroidFromDists(cluster, dists): ...
def _BreadthFirstSplit(cluster, n): ...
def _HeightFirstSplit(cluster, n): ...
def SplitIntoNClusters(cluster, n, breadthFirst: bool = ...): ...
