from _typeshed import Incomplete

class ReFile:
    def readline(self): ...
    def readlines(self): ...
    def rewind(self) -> None: ...
    regExp: Incomplete
    inFile: Incomplete
    def __init__(
        self, fileName, mode: str = ..., comment: str = ..., trailer: str = ...
    ) -> None: ...

def ReadDataFile(fileName, comment: str = ..., depVarCol: int = ..., dataType=...): ...
