from _typeshed import Incomplete
from rdkit import Chem as Chem
from rdkit.VLib.Filter import FilterNode as FilterNode

class DupeFilter(FilterNode):
    _smisSeen: Incomplete
    def __init__(self, **kwargs) -> None: ...
    def reset(self) -> None: ...
    def filter(self, cmpd): ...

def _runDoctests(verbose: Incomplete | None = ...) -> None: ...
