from typing import Any, ClassVar

class EnumeratorType:
    LinkNode: ClassVar[EnumeratorType] = ...
    PositionVariation: ClassVar[EnumeratorType] = ...
    RepeatUnit: ClassVar[EnumeratorType] = ...
    names: ClassVar[dict] = ...
    values: ClassVar[dict] = ...
    __slots__: ClassVar[tuple] = ...

class MolEnumeratorParams:
    __instance_size__: ClassVar[int] = ...
    doRandom: Any
    maxToEnumerate: Any
    randomSeed: Any
    sanitize: Any
    def __init__(self, Any): ...
    @classmethod
    def SetEnumerationOperator(cls, RDKit, Any) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

def Enumerate(RDKit) -> Any: ...
