from _typeshed import Incomplete

class ExcludedVolume:
    index: Incomplete
    featInfo: Incomplete
    exclusionDist: Incomplete
    pos: Incomplete
    def __init__(
        self, featInfo, index: int = ..., exclusionDist: float = ...
    ) -> None: ...
