from _typeshed import Incomplete

hascEntropy: int
_log2: Incomplete

def PyInfoEntropy(results): ...
def PyInfoGain(varMat): ...

InfoEntropy: Incomplete
InfoGain: Incomplete
InfoEntropy = PyInfoEntropy
InfoGain = PyInfoGain
