from _typeshed import Incomplete
from rdkit import Chem as Chem

class FragmentMatcher:
    _onPatt: Incomplete
    _offPatts: Incomplete
    def __init__(self) -> None: ...
    def AddExclusion(self, sma) -> None: ...
    def Init(self, sma) -> None: ...
    def GetSMARTS(self) -> None: ...
    def GetExclusionSMARTS(self) -> None: ...
    def HasMatch(self, mol): ...
    def GetMatch(self, mol): ...
    def GetMatches(self, mol, uniquify: int = ...): ...
    def GetBond(self, idx): ...

def _test(): ...
