from typing import Any

class O3A:
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def Align(cls, RDKit) -> Any: ...
    @classmethod
    def Matches(cls, RDKit) -> Any: ...
    @classmethod
    def Score(cls, RDKit) -> Any: ...
    @classmethod
    def Trans(cls, RDKit) -> Any: ...
    @classmethod
    def Weights(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

def AlignMol(*args, **kwargs) -> Any: ...
def AlignMolConformers(*args, **kwargs) -> Any: ...
def CalcRMS(*args, **kwargs) -> Any: ...
def GetAlignmentTransform(*args, **kwargs) -> Any: ...
def GetBestRMS(*args, **kwargs) -> Any: ...
def GetCrippenO3A(*args, **kwargs) -> Any: ...
def GetCrippenO3AForProbeConfs(*args, **kwargs) -> Any: ...
def GetO3A(*args, **kwargs) -> Any: ...
def GetO3AForProbeConfs(*args, **kwargs) -> Any: ...
def RandomTransform(RDKit) -> Any: ...
