from rdkit import Chem as Chem

class PropertyMol(Chem.Mol):
    __getstate_manages_dict__: bool
    def __init__(self, mol) -> None: ...
    def __getstate__(self): ...
    def __setstate__(self, stateD) -> None: ...

def _test(): ...
