from typing import Any, Optional

from rdkit.Chem.rdchem import QueryAtom

def AAtomQueryAtom(*args, **kwargs) -> Any: ...
def AHAtomQueryAtom(*args, **kwargs) -> Any: ...
def AtomNumEqualsQueryAtom(*args, **kwargs) -> Any: ...
def AtomNumGreaterQueryAtom(*args, **kwargs) -> Any: ...
def AtomNumLessQueryAtom(*args, **kwargs) -> Any: ...
def ExplicitDegreeEqualsQueryAtom(*args, **kwargs) -> Any: ...
def ExplicitDegreeGreaterQueryAtom(*args, **kwargs) -> Any: ...
def ExplicitDegreeLessQueryAtom(*args, **kwargs) -> Any: ...
def ExplicitValenceEqualsQueryAtom(*args, **kwargs) -> Any: ...
def ExplicitValenceGreaterQueryAtom(*args, **kwargs) -> Any: ...
def ExplicitValenceLessQueryAtom(*args, **kwargs) -> Any: ...
def FormalChargeEqualsQueryAtom(*args, **kwargs) -> Any: ...
def FormalChargeGreaterQueryAtom(*args, **kwargs) -> Any: ...
def FormalChargeLessQueryAtom(*args, **kwargs) -> Any: ...
def HCountEqualsQueryAtom(*args, **kwargs) -> Any: ...
def HCountGreaterQueryAtom(*args, **kwargs) -> Any: ...
def HCountLessQueryAtom(*args, **kwargs) -> Any: ...
def HasBitVectPropWithValueQueryAtom(*args, **kwargs) -> Any: ...
def HasBoolPropWithValueQueryAtom(*args, **kwargs) -> Any: ...
def HasBoolPropWithValueQueryBond(*args, **kwargs) -> Any: ...
def HasChiralTagQueryAtom(*args, **kwargs) -> Any: ...
def HasDoublePropWithValueQueryAtom(*args, **kwargs) -> Any: ...
def HasDoublePropWithValueQueryBond(*args, **kwargs) -> Any: ...
def HasIntPropWithValueQueryAtom(
    propname: str,
    val: int,
    negate: Optional[bool] = False,
    tolerance: Optional[int] = 0,
) -> QueryAtom: ...
def HasIntPropWithValueQueryBond(*args, **kwargs) -> Any: ...
def HasPropQueryAtom(*args, **kwargs) -> Any: ...
def HasPropQueryBond(*args, **kwargs) -> Any: ...
def HasStringPropWithValueQueryAtom(*args, **kwargs) -> Any: ...
def HasStringPropWithValueQueryBond(*args, **kwargs) -> Any: ...
def HybridizationEqualsQueryAtom(*args, **kwargs) -> Any: ...
def HybridizationGreaterQueryAtom(*args, **kwargs) -> Any: ...
def HybridizationLessQueryAtom(*args, **kwargs) -> Any: ...
def InNRingsEqualsQueryAtom(*args, **kwargs) -> Any: ...
def InNRingsGreaterQueryAtom(*args, **kwargs) -> Any: ...
def InNRingsLessQueryAtom(*args, **kwargs) -> Any: ...
def IsAliphaticQueryAtom(*args, **kwargs) -> Any: ...
def IsAromaticQueryAtom(*args, **kwargs) -> Any: ...
def IsInRingQueryAtom(*args, **kwargs) -> Any: ...
def IsUnsaturatedQueryAtom(*args, **kwargs) -> Any: ...
def IsotopeEqualsQueryAtom(*args, **kwargs) -> Any: ...
def IsotopeGreaterQueryAtom(*args, **kwargs) -> Any: ...
def IsotopeLessQueryAtom(*args, **kwargs) -> Any: ...
def MAtomQueryAtom(*args, **kwargs) -> Any: ...
def MHAtomQueryAtom(*args, **kwargs) -> Any: ...
def MassEqualsQueryAtom(*args, **kwargs) -> Any: ...
def MassGreaterQueryAtom(*args, **kwargs) -> Any: ...
def MassLessQueryAtom(*args, **kwargs) -> Any: ...
def MinRingSizeEqualsQueryAtom(*args, **kwargs) -> Any: ...
def MinRingSizeGreaterQueryAtom(*args, **kwargs) -> Any: ...
def MinRingSizeLessQueryAtom(*args, **kwargs) -> Any: ...
def MissingChiralTagQueryAtom(*args, **kwargs) -> Any: ...
def NumAliphaticHeteroatomNeighborsEqualsQueryAtom(*args, **kwargs) -> Any: ...
def NumAliphaticHeteroatomNeighborsGreaterQueryAtom(*args, **kwargs) -> Any: ...
def NumAliphaticHeteroatomNeighborsLessQueryAtom(*args, **kwargs) -> Any: ...
def NumHeteroatomNeighborsEqualsQueryAtom(*args, **kwargs) -> Any: ...
def NumHeteroatomNeighborsGreaterQueryAtom(*args, **kwargs) -> Any: ...
def NumHeteroatomNeighborsLessQueryAtom(*args, **kwargs) -> Any: ...
def NumRadicalElectronsEqualsQueryAtom(*args, **kwargs) -> Any: ...
def NumRadicalElectronsGreaterQueryAtom(*args, **kwargs) -> Any: ...
def NumRadicalElectronsLessQueryAtom(*args, **kwargs) -> Any: ...
def QAtomQueryAtom(*args, **kwargs) -> Any: ...
def QHAtomQueryAtom(*args, **kwargs) -> Any: ...
def RingBondCountEqualsQueryAtom(*args, **kwargs) -> Any: ...
def RingBondCountGreaterQueryAtom(*args, **kwargs) -> Any: ...
def RingBondCountLessQueryAtom(*args, **kwargs) -> Any: ...
def TotalDegreeEqualsQueryAtom(*args, **kwargs) -> Any: ...
def TotalDegreeGreaterQueryAtom(*args, **kwargs) -> Any: ...
def TotalDegreeLessQueryAtom(*args, **kwargs) -> Any: ...
def TotalValenceEqualsQueryAtom(*args, **kwargs) -> Any: ...
def TotalValenceGreaterQueryAtom(*args, **kwargs) -> Any: ...
def TotalValenceLessQueryAtom(*args, **kwargs) -> Any: ...
def XAtomQueryAtom(*args, **kwargs) -> Any: ...
def XHAtomQueryAtom(*args, **kwargs) -> Any: ...
