from _typeshed import Incomplete
from rdkit.Chem.Draw.canvasbase import CanvasBase as CanvasBase

class Canvas(CanvasBase):
    _name: Incomplete
    size: Incomplete
    _figure: Incomplete
    _axes: Incomplete
    _dpi: Incomplete
    def __init__(self, size, name: str = ..., imageType: str = ...) -> None: ...
    def rescalePt(self, p1): ...
    def addCanvasLine(
        self, p1, p2, color=..., color2: Incomplete | None = ..., **kwargs
    ) -> None: ...
    def addCanvasText(self, text, pos, font, color=..., **kwargs): ...
    def addCanvasPolygon(self, ps, color=..., **kwargs) -> None: ...
    def addCanvasDashedWedge(
        self, p1, p2, p3, dash=..., color=..., color2: Incomplete | None = ..., **kwargs
    ) -> None: ...
