from _typeshed import Incomplete

class DescriptorCalculator:
    simpleList: Incomplete
    descriptorNames: Incomplete
    compoundList: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def ShowDescriptors(self) -> None: ...
    def GetDescriptorNames(self) -> None: ...
    def SaveState(self, fileName) -> None: ...
    def CalcDescriptors(self, what, *args, **kwargs) -> None: ...
