from numpy import *
from _typeshed import Incomplete
from rdkit.sping import pid as pid

def DrawSpiral(
    canvas,
    startColor,
    endColor,
    startRadius,
    endRadius,
    nLoops,
    degsPerSlice: int = ...,
    degsPerStep: int = ...,
    startAngle: int = ...,
    centerPos: Incomplete | None = ...,
    dir: int = ...,
) -> None: ...
