from rdkit import Chem as Chem, Geometry as Geometry

def cross(v1, v2): ...
def findNeighbors(atomId, adjMat): ...
def _findAvgVec(conf, center, nbrs): ...
def GetAromaticFeatVects(conf, featAtoms, featLoc, scale: float = ...): ...
def ArbAxisRotation(theta, ax, pt): ...
def GetAcceptor2FeatVects(conf, featAtoms, scale: float = ...): ...
def _GetTetrahedralFeatVect(conf, aid, scale): ...
def GetDonor3FeatVects(conf, featAtoms, scale: float = ...): ...
def GetAcceptor3FeatVects(conf, featAtoms, scale: float = ...): ...
def _findHydAtoms(nbrs, atomNames): ...
def _checkPlanarity(conf, cpt, nbrs, tol: float = ...): ...
def GetDonor2FeatVects(conf, featAtoms, scale: float = ...): ...
def GetDonor1FeatVects(conf, featAtoms, scale: float = ...): ...
def GetAcceptor1FeatVects(conf, featAtoms, scale: float = ...): ...
