from _typeshed import Incomplete
from rdkit.ML.Descriptors import Descriptors as Descriptors
from rdkit.RDLogger import logger as logger

class MolecularDescriptorCalculator(Descriptors.DescriptorCalculator):
    simpleList: Incomplete
    descriptorNames: Incomplete
    compoundList: Incomplete
    def __init__(self, simpleList, *args, **kwargs) -> None: ...
    descriptorVersions: Incomplete
    def _findVersions(self) -> None: ...
    def SaveState(self, fileName) -> None: ...
    def CalcDescriptors(self, mol, *args, **kwargs): ...
    def GetDescriptorNames(self): ...
    def GetDescriptorSummaries(self): ...
    def GetDescriptorFuncs(self): ...
    def GetDescriptorVersions(self): ...
