from _typeshed import Incomplete

def _CenterTForm(dataSet) -> None: ...
def _NormalizeTForm(dataSet) -> None: ...
def _StandardTForm(dataSet) -> None: ...

_availTransforms: Incomplete

def GetAvailTransforms(): ...
