from rdkit.Dbase.DbConnection import DbConnect as DbConnect
from rdkit.ML import ScreenComposite as ScreenComposite
from rdkit.ML.Data import Stats as Stats
from rdkit.ML.DecTree import Tree as Tree, TreeUtils as TreeUtils

__VERSION_STRING: str

def ProcessIt(composites, nToConsider: int = ..., verbose: int = ...): ...
def ErrorStats(conn, where, enrich: int = ...): ...
def ShowStats(statD, enrich: int = ...) -> None: ...
def Usage() -> None: ...
