from _typeshed import Incomplete
from rdkit import RDLogger as RDLogger

logger: Incomplete

def EuclideanDist(pi, pj): ...
def ClusterData(
    data, nPts, distThresh, isDistData: bool = ..., distFunc=..., reordering: bool = ...
): ...
