from _typeshed import Incomplete

def EuclideanDistance(inData): ...
def CalcMetricMatrix(inData, metricFunc): ...
def FindMinValInList(mat, nObjs, minIdx: Incomplete | None = ...): ...
def ShowMetricMat(metricMat, nObjs) -> None: ...

methods: Incomplete
