from . import rdMolDraw2D as rdMolDraw2D
from _typeshed import Incomplete
from rdkit import Chem as Chem

rdkitStructureRendererJsUrl: str
minimalLibJsUrl: str
parentNodeQuery: str
_enabled: bool
_camelCaseOptToTagRe: Incomplete
_opts: str
_disabled: str
_defaultDrawOptions: Incomplete
_defaultDrawOptionsDict: Incomplete

def _isAcceptedKeyValue(key, value): ...
def _getValueFromKey(d, key): ...
def _molDrawOptionsToDict(molDrawOptions=...): ...
def _isDrawOptionEqual(v1, v2): ...
def filterDefaultDrawOpts(molDrawOptions): ...
def setEnabled(): ...
def isEnabled(mol: Incomplete | None = ...): ...
def getOpts(mol): ...
def setOpts(mol, opts) -> None: ...
def setOpt(mol, key, value) -> None: ...
def clearOpts(mol) -> None: ...
def clearOpt(mol, key) -> None: ...
def setNoInteractive(mol, shouldSet: bool = ...) -> None: ...
def isNoInteractive(mol): ...
def injectHTMLHeaderBeforeTable(html): ...
def generateHTMLHeader(doc, element): ...
def newlineToXml(molblock): ...
def xmlToNewline(xmlblock): ...
def toDataMol(mol): ...
def _dashLower(m): ...
def camelCaseOptToDataTag(opt): ...
def generateHTMLBody(useSvg, mol, size, drawOptions: Incomplete | None = ...): ...
