from typing import Any

class Snapshot:
    def __init__(self, RDKit): ...
    @classmethod
    def GetEnergy(cls, RDKit) -> Any: ...
    @classmethod
    def GetPoint2D(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def GetPoint3D(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def SetEnergy(cls, RDKit, double) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

class Trajectory:
    def __init__(self, RDKit): ...
    @classmethod
    def AddConformersToMol(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def AddSnapshot(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def Clear(cls, RDKit) -> Any: ...
    @classmethod
    def Dimension(cls, RDKit) -> Any: ...
    @classmethod
    def GetSnapshot(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def InsertSnapshot(cls, *args, **kwargs) -> Any: ...
    @classmethod
    def NumPoints(cls, RDKit) -> Any: ...
    @classmethod
    def RemoveSnapshot(cls, RDKit, unsignedint) -> Any: ...
    @classmethod
    def __len__(cls, RDKit) -> Any: ...
    @classmethod
    def __reduce__(cls) -> Any: ...

def ReadAmberTrajectory(*args, **kwargs) -> Any: ...
def ReadGromosTrajectory(*args, **kwargs) -> Any: ...
