from _typeshed import Incomplete
from rdkit import Chem as Chem

aldehydePatt: Incomplete
ketonePatt: Incomplete
amidePatt: Incomplete
esterPatt: Incomplete
carboxylatePatt: Incomplete
carboxylPatt: Incomplete
specialCases: Incomplete

def SATISTypes(mol, neighborsToInclude: int = ...): ...
