from rdkit import Chem as Chem

def GetPrincipleQuantumNumber(atNum): ...
def EStateIndices(mol, force: bool = ...): ...
def MaxEStateIndex(mol, force: int = ...): ...
def MinEStateIndex(mol, force: int = ...): ...
def MaxAbsEStateIndex(mol, force: int = ...): ...
def MinAbsEStateIndex(mol, force: int = ...): ...
def _exampleCode() -> None: ...
