from _typeshed import Incomplete
from rdkit import DataStructs as DataStructs

class BitClusterer:
    _clusters: Incomplete
    _bidList: Incomplete
    _nClusters: Incomplete
    _type: Incomplete
    def __init__(self, idList, nCluster, type=...) -> None: ...
    def ClusterBits(self, corrMat) -> None: ...
    def SetClusters(self, clusters) -> None: ...
    def GetClusters(self): ...
    def MapToClusterScores(self, fp): ...
    def MapToClusterFP(self, fp): ...
