from _typeshed import Incomplete
from rdkit import Chem as Chem, RDConfig as RDConfig
from rdkit.Chem.Suppliers import DbMolSupplier as DbMolSupplier
from rdkit.VLib.Supply import SupplyNode as SupplyNode

class DbMolSupplyNode(SupplyNode):
    _dbResults: Incomplete
    _supplier: Incomplete
    def __init__(self, dbResults, **kwargs) -> None: ...
    def reset(self) -> None: ...
    def next(self): ...

def GetNode(dbName, tableName): ...
def _test(): ...
